C Programmer: Chris Burke
C Date: June 23, 1997
C Purpose: From particle temperatures get u,b,v sum from table
C add all these up to get total sums then find magnitude

c	modified 11/9/97 by Jim Simpson. Set hard limits on tval small
c	and large to try to get rid of the NaNs. Also some slight 
c	rearranging.

      Subroutine mags

C Declare variables

      implicit none
      include 'comblock'
      include 'tubecom'
      integer kmin,msum,i,j,k,tsum
      double precision uxtot,btot,vtot,uxextra,bextra,vextra,bxtot
      double precision tval,rtot,etot,rextra,bxextra,eextra
      double precision rsum,esum,bxsum,uxsum,bsum,vsum,smallt,larget

C Begin subroutine

      msum=0
      tsum=0
      uxtot=0.0d0
      bxtot=0.0d0
      btot=0.0d0
      vtot=0.0d0
      rtot=0.0d0
      etot=0.0d0
	smallt=dlog10(5.0d2)
	larget=dlog10(1.0d5)

C Find the magnitude from a single tube

      Do i=1,ntt
         if(headtub(i).eq.0) go to 3
         k=headtub(i)
	 uxsum=0.0d0
	 bxsum=0.0d0
	 bsum=0.0d0
	 vsum=0.0d0
	 rsum=0.0d0
	 esum=0.0d0
	 tsum=tsum+1
         kmin=k-min(k,numpart)+1
         Do j=k,kmin,-1

C Make sure temp doesn't explode when taking log. If not, squishy happens.

            if (temperature(tublist(j,i)).le.1.0) then
	     goto 6
	    else
	     tval=dble(sfs*log10(temperature(tublist(j,i)))+sft)
	     msum=msum+1
	    end if
   
C Make sure temperature is within bounds of table. If not, make it fit!

            if (tval.le.smallt) then
	     tval=smallt
	    else if(tval.ge.larget) then
	     tval=larget
	    end if

C Interpolate from table to get magnitudes

            call splint(temps,uxsums,uxsums2,numtemps,tval,uxextra)
            call splint(temps,bxsums,bxsums2,numtemps,tval,bxextra)
            call splint(temps,bsums,bsums2,numtemps,tval,bextra)
            call splint(temps,vsums,vsums2,numtemps,tval,vextra)
            call splint(temps,rsums,rsums2,numtemps,tval,rextra)
            call splint(temps,esums,esums2,numtemps,tval,eextra)

C Reduce magnitudes using limb darkening and add to subtotals.

            uxsum=uxsum+uxextra*zcomp(i)
            bxsum=bxsum+bxextra*zcomp(i)
            bsum=bsum+bextra*zcomp(i)
            vsum=vsum+vextra*zcomp(i)
            rsum=rsum+rextra*zcomp(i)
            esum=esum+eextra*zcomp(i)

 6          continue

C finished with single particle

      End do

c add subtotals to totals

      uxtot=uxtot+uxsum
      bxtot=bxtot+bxsum
      btot=btot+bsum
      vtot=vtot+vsum
      rtot=rtot+rsum
      etot=etot+esum

 3    continue

C Finished with single tube

      End do

C Find total magnitudes

      valux(anglei)=(-2.5)*DLOG10(uxtot)
      valbx(anglei)=(-2.5)*DLOG10(bxtot)
      valb(anglei)=(-2.5)*DLOG10(btot)
      valv(anglei)=(-2.5)*DLOG10(vtot)
      valr(anglei)=(-2.5)*DLOG10(rtot)
      vali(anglei)=(-2.5)*DLOG10(etot)

      partcnt(anglei)=msum
      tubcnt(anglei)=tsum


      Return
      End

